@@ -1,5 +1,5 @@
 package LWP::ConsoleLogger::Easy;
-$LWP::ConsoleLogger::Easy::VERSION = '0.000022';
+$LWP::ConsoleLogger::Easy::VERSION = '0.000023';
 use strict;
 use warnings;
 
@@ -35,7 +35,7 @@ sub debug_ua {
                 my $content_type = shift;
                 my $base_url     = shift;
 
-                return $text unless $content_type =~ m{html}i;
+                return $text unless $content_type && $content_type =~ m{html}i;
 
                 return (
                     trim(
@@ -82,7 +82,7 @@ LWP::ConsoleLogger::Easy - Easy LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000022
+version 0.000023
 
 =head1 SYNOPSIS
 
